@@ -27,6 +27,7 @@ class CommunityFields(enum.Enum):
     EVAL_CONFIG = "evalconfig"
     PAIRS = "pairs"
     EXCHANGES = "exchanges"
+    EXCHANGE_TYPES = "exchangetypes"
     NOTIFICATIONS = "notifications"
     TYPE = "type"
     PLATFORM = "platform"
@@ -37,3 +38,9 @@ class CommunityFields(enum.Enum):
     SUPPORTS = "supports"
     ROLES = "roles"
     DONATIONS = "donations"
+    SIGNAL_EMITTER = "signalemitter"
+    SIGNAL_RECEIVER = "signalreceiver"
+    COMMUNITY_BOT_TYPE = "communitybottype"
+    PROFILE_NAME = "profilename"
+    PROFILE_ID = "profileid"
+    PROFILE_IMPORTED = "profileimported"
