@@ -18,8 +18,8 @@ import time
 import uuid
 import aiohttp
 
-import octobot_commons.enums as enums
 import octobot_commons.constants as commons_constants
+import octobot_commons.enums as commons_enums
 import octobot_commons.logging as logging
 import octobot_commons.configuration as configuration
 import octobot_commons.signals as signals
@@ -119,7 +119,7 @@ class OctoBot:
         await logger.init_octobot_chan_logger(self.bot_id)
         await self.create_producers()
         await self.start_producers()
-        await system_resources_watcher.start_system_resources_watcher()
+        await self._ensure_watchers()
         await self._post_initialize()
 
     async def create_producers(self):
@@ -143,7 +143,7 @@ class OctoBot:
         self.configuration_manager.add_element(constants.TENTACLES_SETUP_CONFIG_KEY, self.tentacles_setup_config)
         await service_api.send_notification(
             service_api.create_notification(f"{constants.PROJECT_NAME} {constants.LONG_VERSION} is starting ...",
-                                            markdown_format=enums.MarkdownFormat.ITALIC)
+                                            markdown_format=commons_enums.MarkdownFormat.ITALIC)
         )
         if self.startup_messages:
             for limit_message in self.startup_messages:
@@ -204,9 +204,13 @@ class OctoBot:
         self.community_handler = community.CommunityManager(self.octobot_api)
 
     async def _ensure_clock(self):
-        if trading_api.is_trader_enabled_in_config(self.config):
+        if trading_api.is_trader_enabled_in_config(self.config) and constants.ENABLE_CLOCK_SYNCH:
             await os_clock_sync.start_clock_synchronizer()
 
+    async def _ensure_watchers(self):
+        if constants.ENABLE_SYSTEM_WATCHER:
+            await system_resources_watcher.start_system_resources_watcher()
+
     def _log_config(self):
         exchanges = [
             f"{exchange}[{config.get(commons_constants.CONFIG_EXCHANGE_TYPE, commons_constants.CONFIG_EXCHANGE_SPOT)}]"
