@@ -13,9 +13,10 @@
 #
 #  You should have received a copy of the GNU General Public
 #  License along with OctoBot. If not, see <https://www.gnu.org/licenses/>.
+import asyncio
+
 import octobot_commons.enums as common_enums
 import octobot_commons.constants as common_constants
-import octobot_commons.errors as common_errors
 
 import octobot_trading.api as trading_api
 import octobot_trading.octobot_channel_consumer as trading_channel_consumer
@@ -32,16 +33,29 @@ class ExchangeProducer(octobot_channel.OctoBotChannelProducer):
         self.backtesting = backtesting
         self.exchange_manager_ids = []
 
+        self.to_create_exchanges_count = 0
+        self.created_all_exchanges = asyncio.Event()
+
     async def start(self):
-        self._init_bot_storage()
+        self.to_create_exchanges_count = 0
+        self.created_all_exchanges.clear()
         for exchange_name in self.octobot.config[common_constants.CONFIG_EXCHANGES]:
             if self.octobot.config[common_constants.CONFIG_EXCHANGES][exchange_name].get(
                     common_constants.CONFIG_ENABLED_OPTION, True):
                 await self.create_exchange(exchange_name, self.backtesting)
+                self.to_create_exchanges_count += 1
+
+    def register_created_exchange_id(self, exchange_id):
+        self.exchange_manager_ids.append(exchange_id)
+        if len(self.exchange_manager_ids) == self.to_create_exchanges_count:
+            self.created_all_exchanges.set()
+            self.logger.debug(f"Exchange(s) created")
 
     async def stop(self):
+        self.logger.debug("Stopping ...")
         for exchange_manager in trading_api.get_exchange_managers_from_exchange_ids(self.exchange_manager_ids):
             await trading_api.stop_exchange(exchange_manager)
+        self.logger.debug("Stopped")
 
     async def create_exchange(self, exchange_name, backtesting):
         await self.send(bot_id=self.octobot.bot_id,
@@ -57,9 +71,3 @@ class ExchangeProducer(octobot_channel.OctoBotChannelProducer):
                                 self.octobot.config,
                             trading_channel_consumer.OctoBotChannelTradingDataKeys.EXCHANGE_NAME.value: exchange_name,
                         })
-
-    def _init_bot_storage(self):
-        try:
-            trading_api.init_bot_storage(self.octobot.bot_id, self.octobot.config, self.octobot.tentacles_setup_config)
-        except common_errors.ConfigTradingError as e:
-            self.logger.info(f"Skipping bot storage creation: {e}")
